:github_url: https://github.com/felavila/qumas

qumas documentation
=====================


.. toctree::
   :maxdepth: 2
   :caption: Getting Started 
   
   getting_started

.. toctree::
   :maxdepth: 2
   :caption: Examples

   examples/index

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   api/qumas
   tables

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`